==> MoarSigns-1.9.4-3.3.1.3-sources.jar: gory_moon/moarsigns/client/layer/LayerMoarSign.java <==
package gory_moon.moarsigns.client.layer;

import gory_moon.moarsigns.client.models.ModelMoarSign;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.FontRenderer;
import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.client.renderer.entity.layers.LayerRenderer;
import net.minecraft.entity.EntityLivingBase;
import net.minecraft.util.ResourceLocation;
import org.lwjgl.opengl.GL11;

/**
 * Just playing atound a bit, no permanent code
 */
public class LayerMoarSign implements LayerRenderer {

    private ModelMoarSign modelMoarSign;
    private ResourceLocation texture = new ResourceLocation("moarsigns:textures/signs/metal/diamond_sign.png");

    public LayerMoarSign() {
        modelMoarSign = new ModelMoarSign();
        modelMoarSign.stick.field_78806_j = false;
    }

    @Override
    public void func_177141_a(EntityLivingBase entityLivingbase, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch, float scale) {
        if (entityLivingbase.func_70005_c_().equals("Gory_Moon") && !entityLivingbase.func_82150_aj()) {
            GlStateManager.func_179094_E();
            GlStateManager.func_179109_b(0.0F, 0.0F, 0.15F);
            float f = 0.3333334F;
            GlStateManager.func_179152_a(f, -f, -f);
            Minecraft.func_71410_x().field_71446_o.func_110577_a(texture);
            modelMoarSign.render();
            GlStateManager.func_179121_F();

            FontRenderer fontRenderer = Minecraft.func_71410_x().field_71466_p;

            GlStateManager.func_179094_E();
            int size = 5;
            float f1 = 0.016666668F * f + (size / 1000F);;
            //GlStateManager.translate(size > 0 ? 0.01F : 0.0F, 0.5F * f - ((float) 0.02 * size) - (size < 2 ? 0 : size < 7 ? 0.01F : size < 11 ? 0.02F : size < 16 ? 0.03F : size < 20 ? 0.035F : 0.037F), 0.07F * f);
            GlStateManager.func_179109_b(0.0F, 0.043F, 0.1709F);
            GlStateManager.func_179152_a(-f1, f1, f1);
            GL11.glNormal3f(0.0F, 0.0F, -1.0F * f1);
            GlStateManager.func_179131_c(1.0F, 1.0F, 1.0F, 1.0F);
            GlStateManager.func_179132_a(false);


            GlStateManager.func_179140_f();

            String s = "§eMoar";
            String s1 = "§6Signs";
            fontRenderer.func_175065_a(s, -fontRenderer.func_78256_a(s) / 2, 2, 0, true);
            fontRenderer.func_175065_a(s1, -fontRenderer.func_78256_a(s1) / 2, 12, 0, true);

            GlStateManager.func_179145_e();

            GlStateManager.func_179132_a(true);
            GlStateManager.func_179121_F();
        }
    }

    @Override
    public boolean func_177142_b() {
        return false;
    }
}

==> MoarSigns-1.10.2-4.1.0.5-sources.jar: gory_moon/moarsigns/client/layer/LayerMoarSign.java <==
package gory_moon.moarsigns.client.layer;

import gory_moon.moarsigns.client.models.ModelMoarSign;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.FontRenderer;
import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.client.renderer.entity.layers.LayerRenderer;
import net.minecraft.entity.EntityLivingBase;
import net.minecraft.util.ResourceLocation;
import org.lwjgl.opengl.GL11;

/**
 * Just playing around a bit, no permanent code
 */
public class LayerMoarSign implements LayerRenderer {

    private ModelMoarSign modelMoarSign;
    private ResourceLocation texture = new ResourceLocation("moarsigns:textures/signs/metal/diamond_sign.png");

    public LayerMoarSign() {
        modelMoarSign = new ModelMoarSign();
        modelMoarSign.stick.field_78806_j = false;
    }

    @Override
    public void func_177141_a(EntityLivingBase entityLivingbase, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch, float scale) {
        if (entityLivingbase.func_70005_c_().equals("Gory_Moon") && !entityLivingbase.func_82150_aj()) {
            float sneak = entityLivingbase.func_70093_af()? 0.1F: 0.0F;
            GlStateManager.func_179094_E();
            GlStateManager.func_179109_b(0.0F, 0.0F + sneak, 0.15F);
            float f = 0.3333334F;
            GlStateManager.func_179152_a(f, -f, -f);
            if (sneak > 0) {
                GlStateManager.func_179114_b(30, 0, 0, 0);
                GlStateManager.func_179109_b(0.0F, 0.0F, 0.12F);
            }
            Minecraft.func_71410_x().field_71446_o.func_110577_a(texture);
            modelMoarSign.render();
            GlStateManager.func_179121_F();

            FontRenderer fontRenderer = Minecraft.func_71410_x().field_71466_p;


            GlStateManager.func_179094_E();
            int size = 5;
            float f1 = 0.016666668F * f + (size / 1000F);;
            //GlStateManager.translate(size > 0 ? 0.01F : 0.0F, 0.5F * f - ((float) 0.02 * size) - (size < 2 ? 0 : size < 7 ? 0.01F : size < 11 ? 0.02F : size < 16 ? 0.03F : size < 20 ? 0.035F : 0.037F), 0.07F * f);
            GlStateManager.func_179109_b(0.0F, 0.043F + sneak, 0.1709F);
            GlStateManager.func_179152_a(-f1, f1, f1);
            if (sneak > 0) {
                GlStateManager.func_179114_b(30, 0, 0, 0);
                GlStateManager.func_179109_b(0.0F, 0.0F, 0.12F);
            }
            GL11.glNormal3f(0.0F, 0.0F, -1.0F * f1);
            GlStateManager.func_179131_c(1.0F, 1.0F, 1.0F, 1.0F);
            GlStateManager.func_179132_a(false);


            GlStateManager.func_179140_f();

            String s = "§eMoar";
            String s1 = "§6Signs";
            fontRenderer.func_175065_a(s, -fontRenderer.func_78256_a(s) / 2, 2, 0, true);
            fontRenderer.func_175065_a(s1, -fontRenderer.func_78256_a(s1) / 2, 12, 0, true);

            GlStateManager.func_179145_e();

            GlStateManager.func_179132_a(true);
            GlStateManager.func_179121_F();
        }
    }

    @Override
    public boolean func_177142_b() {
        return false;
    }
}
